==> AffyCompatible_1.10.0.zip: AffyCompatible/doc/NetAffxResource.R <==
###################################################
### chunk number 1: setup
###################################################
#line 38 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
library(AffyCompatible)


###################################################
### chunk number 2: rsrc-setup
###################################################
#line 59 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
password <- "jnkdna"


###################################################
### chunk number 3: rsrc
###################################################
#line 62 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
rsrc <- NetAffxResource(user="mtmorgan@fhcrc.org", password=password)
rsrc


###################################################
### chunk number 4: names
###################################################
#line 75 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
head(names(rsrc))
affxDescription(rsrc[["Bovine"]])


###################################################
### chunk number 5: select-anno
###################################################
#line 93 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
annos <- rsrc[["Porcine"]]
annos


###################################################
### chunk number 6: anno-class
###################################################
#line 100 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
sapply(affxAnnotation(annos), force)[1:5]
anno <- affxAnnotation(annos)[[3]]
anno


###################################################
### chunk number 7: select-anno-idx
###################################################
#line 110 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
anno <- rsrc[["Porcine", "BLASTP annotations, CSV Format"]]
anno <- rsrc[["Porcine", 3]]


###################################################
### chunk number 8: readAnnotation
###################################################
#line 116 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
df <- readAnnotation(rsrc, annotation=anno)


###################################################
### chunk number 9: anno-free-form
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpDscMbj/R.INSTALL48d31266/AffyCompatible/inst/doc/NetAffxResource.Rnw"
anno <- rsrc[["Porcine", "PSI Library File"]]
fl <- readAnnotation(rsrc, annotation=anno, content=FALSE)
fl
## a zip file, containing 'Porcine.psi'
conn <- unz(fl, "Porcine.psi")
readLines(conn, n=6)
read.table(conn, header=FALSE, skip=1, sep="\t", nrows=5)

==> AffyCompatible_1.12.0.zip: AffyCompatible/doc/NetAffxResource.R <==
###################################################
### chunk number 1: setup
###################################################
#line 38 "NetAffxResource.Rnw"
library(AffyCompatible)


###################################################
### chunk number 2: rsrc-setup
###################################################
#line 59 "NetAffxResource.Rnw"
password <- "jnkdna"


###################################################
### chunk number 3: rsrc
###################################################
#line 62 "NetAffxResource.Rnw"
rsrc <- NetAffxResource(user="mtmorgan@fhcrc.org", password=password)
rsrc


###################################################
### chunk number 4: names
###################################################
#line 75 "NetAffxResource.Rnw"
head(names(rsrc))
affxDescription(rsrc[["Bovine"]])


###################################################
### chunk number 5: select-anno
###################################################
#line 93 "NetAffxResource.Rnw"
annos <- rsrc[["Porcine"]]
annos


###################################################
### chunk number 6: anno-class
###################################################
#line 100 "NetAffxResource.Rnw"
sapply(affxAnnotation(annos), force)[1:5]
anno <- affxAnnotation(annos)[[3]]
anno


###################################################
### chunk number 7: select-anno-idx
###################################################
#line 110 "NetAffxResource.Rnw"
anno <- rsrc[["Porcine", "BLASTP annotations, CSV Format"]]
anno <- rsrc[["Porcine", 3]]


###################################################
### chunk number 8: readAnnotation
###################################################
#line 116 "NetAffxResource.Rnw"
df <- readAnnotation(rsrc, annotation=anno)


###################################################
### chunk number 9: anno-free-form
###################################################
#line 137 "NetAffxResource.Rnw"
anno <- rsrc[["Porcine", "PSI Library File"]]
fl <- readAnnotation(rsrc, annotation=anno, content=FALSE)
fl
## a zip file, containing 'Porcine.psi'
conn <- unz(fl, "Porcine.psi")
readLines(conn, n=6)
read.table(conn, header=FALSE, skip=1, sep="\t", nrows=5)
